Package: opalr
Version: 3.6.1
Title: 'Opal' Data Repository Client and 'DataSHIELD' Utils
Authors@R: 
    c(person(given = "Yannick",
             family = "Marcon",
             role = c("aut", "cre"),
             email = "yannick.marcon@obiba.org",
             comment = c(ORCID = "0000-0003-0138-2023")),
      person(given = "Amadou",
             family = "Gaye",
             role = "ctb",
             comment = c(ORCID = "0000-0002-1180-2792")),
      person("OBiBa group",
             role="cph",
             email="info@obiba.org"))
Depends: R (>= 3.1), httr
Imports: jsonlite, readr, mime, progress, labelled, tibble
Suggests: e1071, knitr, knitrBootstrap, rmarkdown, testthat
Description: Data integration Web application for biobanks by 'OBiBa'. 'Opal' is
    the core database application for biobanks. Participant data, once
    collected from any data source, must be integrated and stored in a central
    data repository under a uniform model. 'Opal' is such a central repository.
    It can import, process, validate, query, analyze, report, and export data.
    'Opal' is typically used in a research center to analyze the data acquired at
    assessment centres. Its ultimate purpose is to achieve seamless
    data-sharing among biobanks. This 'Opal' client allows to interact with 'Opal'
    web services and to perform operations on the R server side. 'DataSHIELD'
    administration tools are also provided.
License: GPL-3
URL: https://github.com/obiba/opalr/, https://www.obiba.org/opalr/,
        https://www.obiba.org/pages/products/opal/,
        https://academic.oup.com/ije/article/46/5/1372/4102813,
        https://journals.plos.org/ploscompbiol/article?id=10.1371/journal.pcbi.1008880,
        https://datashield.org/
BugReports: https://github.com/obiba/opalr/issues
VignetteBuilder: knitr
Encoding: UTF-8
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-27 07:35:33 UTC; yannick
Author: Yannick Marcon [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0138-2023>),
  Amadou Gaye [ctb] (ORCID: <https://orcid.org/0000-0002-1180-2792>),
  OBiBa group [cph]
Maintainer: Yannick Marcon <yannick.marcon@obiba.org>
Repository: CRAN
Date/Publication: 2026-05-27 08:00:09 UTC
Built: R 4.5.2; ; 2026-05-27 11:39:18 UTC; unix
