# Generated by roxygen2: do not edit by hand

S3method(print,opal)
export(dictionary.annotate)
export(dictionary.annotate.harmo_status)
export(dictionary.annotations)
export(dictionary.apply)
export(dictionary.inspect)
export(dsadmin.activity)
export(dsadmin.activity_summary)
export(dsadmin.get_method)
export(dsadmin.get_methods)
export(dsadmin.get_options)
export(dsadmin.install_github_package)
export(dsadmin.install_local_package)
export(dsadmin.install_package)
export(dsadmin.installed_package)
export(dsadmin.log)
export(dsadmin.package_description)
export(dsadmin.package_descriptions)
export(dsadmin.perm)
export(dsadmin.perm_add)
export(dsadmin.perm_delete)
export(dsadmin.profile)
export(dsadmin.profile_access)
export(dsadmin.profile_create)
export(dsadmin.profile_delete)
export(dsadmin.profile_enable)
export(dsadmin.profile_exists)
export(dsadmin.profile_init)
export(dsadmin.profile_perm)
export(dsadmin.profile_perm_add)
export(dsadmin.profile_perm_delete)
export(dsadmin.profile_rparser)
export(dsadmin.profiles)
export(dsadmin.publish_package)
export(dsadmin.remove_package)
export(dsadmin.rm_method)
export(dsadmin.rm_methods)
export(dsadmin.rm_option)
export(dsadmin.rm_options)
export(dsadmin.rm_package_methods)
export(dsadmin.set_method)
export(dsadmin.set_option)
export(dsadmin.set_package_methods)
export(dsadmin.unpublish_package)
export(oadmin.activity)
export(oadmin.activity_summary)
export(oadmin.install_bioconductor_package)
export(oadmin.install_cran_package)
export(oadmin.install_devtools)
export(oadmin.install_github_package)
export(oadmin.install_local_package)
export(oadmin.install_package)
export(oadmin.installed_devtools)
export(oadmin.installed_package)
export(oadmin.installed_packages)
export(oadmin.log)
export(oadmin.log_rest)
export(oadmin.log_sql)
export(oadmin.package_description)
export(oadmin.perm)
export(oadmin.perm_add)
export(oadmin.perm_delete)
export(oadmin.r_perm)
export(oadmin.r_perm_add)
export(oadmin.r_perm_delete)
export(oadmin.remove_package)
export(oadmin.system_metrics)
export(oadmin.system_perm)
export(oadmin.system_perm_add)
export(oadmin.system_perm_delete)
export(oadmin.user_add)
export(oadmin.user_delete)
export(oadmin.user_enable)
export(oadmin.user_exists)
export(oadmin.user_profile_delete)
export(oadmin.user_profiles)
export(oadmin.user_reset_password)
export(oadmin.users)
export(opal.annotate)
export(opal.annotations)
export(opal.as_md_table)
export(opal.assign)
export(opal.assign.data)
export(opal.assign.resource)
export(opal.assign.script)
export(opal.assign.table)
export(opal.assign.table.tibble)
export(opal.attribute_values)
export(opal.command)
export(opal.command_result)
export(opal.command_rm)
export(opal.commands)
export(opal.commands_rm)
export(opal.datasource)
export(opal.datasources)
export(opal.delete)
export(opal.execute)
export(opal.execute.source)
export(opal.file)
export(opal.file_cp)
export(opal.file_download)
export(opal.file_info)
export(opal.file_ls)
export(opal.file_mkdir)
export(opal.file_mkdir_tmp)
export(opal.file_mv)
export(opal.file_read)
export(opal.file_rm)
export(opal.file_unzip)
export(opal.file_upload)
export(opal.file_write)
export(opal.get)
export(opal.load_package)
export(opal.login)
export(opal.logout)
export(opal.perms)
export(opal.post)
export(opal.profiles)
export(opal.project)
export(opal.project_backup)
export(opal.project_command)
export(opal.project_create)
export(opal.project_delete)
export(opal.project_exists)
export(opal.project_perm)
export(opal.project_perm_add)
export(opal.project_perm_delete)
export(opal.project_restore)
export(opal.projects)
export(opal.projects_databases)
export(opal.put)
export(opal.report)
export(opal.resource)
export(opal.resource_create)
export(opal.resource_delete)
export(opal.resource_exists)
export(opal.resource_extension_create)
export(opal.resource_get)
export(opal.resource_perm)
export(opal.resource_perm_add)
export(opal.resource_perm_delete)
export(opal.resource_view_create)
export(opal.resource_view_reconnect)
export(opal.resources)
export(opal.resources_perm)
export(opal.resources_perm_add)
export(opal.resources_perm_delete)
export(opal.rm)
export(opal.session)
export(opal.session_delete)
export(opal.session_events)
export(opal.session_exists)
export(opal.session_get)
export(opal.session_running)
export(opal.sql)
export(opal.sql_history)
export(opal.symbol_import)
export(opal.symbol_rm)
export(opal.symbol_save)
export(opal.symbols)
export(opal.table)
export(opal.table_create)
export(opal.table_delete)
export(opal.table_dictionary_get)
export(opal.table_dictionary_update)
export(opal.table_exists)
export(opal.table_export)
export(opal.table_get)
export(opal.table_import)
export(opal.table_perm)
export(opal.table_perm_add)
export(opal.table_perm_delete)
export(opal.table_save)
export(opal.table_truncate)
export(opal.table_view_create)
export(opal.table_view_update)
export(opal.tables)
export(opal.tables_perm)
export(opal.tables_perm_add)
export(opal.tables_perm_delete)
export(opal.task)
export(opal.task_cancel)
export(opal.task_delete)
export(opal.task_wait)
export(opal.tasks)
export(opal.taxonomies)
export(opal.taxonomy)
export(opal.taxonomy_delete)
export(opal.taxonomy_download)
export(opal.taxonomy_upload)
export(opal.terms)
export(opal.token)
export(opal.token_datashield_create)
export(opal.token_delete)
export(opal.token_r_create)
export(opal.token_renew)
export(opal.token_sql_create)
export(opal.tokens)
export(opal.unload_package)
export(opal.valueset)
export(opal.variable)
export(opal.variable_summary)
export(opal.variables)
export(opal.version_compare)
export(opal.vocabularies)
export(opal.vocabulary)
export(opal.workspace_restore)
export(opal.workspace_rm)
export(opal.workspace_save)
export(opal.workspaces)
import(httr)
import(jsonlite)
import(labelled)
import(mime)
import(progress)
import(readr)
import(tibble)
import(tools)
import(utils)
